@@ -9,3 +9,7 @@ import (
 func writeProcessMetrics(w io.Writer) {
 	// TODO: implement it
 }
+
+func writeFDMetrics(w io.Writer) {
+	// TODO: implement it.
+}
